# `gluonts.ext`

GluonTS extra models.

This module contains models which are not written using PyTorch and MXNet, and
therefore can't go into the `gluonts.torch` and `gluonts.mx` subpackages.

Each model might require additional dependencies which need to be installed
before the model can be used.
